diff --git a/lib/libalpm/conflict.c b/lib/libalpm/conflict.c
index d09c996..b05a789 100644
--- a/lib/libalpm/conflict.c
+++ b/lib/libalpm/conflict.c
@@ -95,7 +95,7 @@ static void add_conflict(alpm_list_t **baddeps, const char *pkg1,
  * @param *baddeps list to store conflicts
  * @param order if >= 0 the conflict order is preserved, if < 0 it's reversed
  */
-static void check_conflict(alpm_list_t *list1, alpm_list_t *list2,
+void SYMEXPORT check_conflict(alpm_list_t *list1, alpm_list_t *list2,
 		alpm_list_t **baddeps, int order) {
 	alpm_list_t *i, *j, *k;
 
diff --git a/lib/libalpm/conflict.h b/lib/libalpm/conflict.h
index 8928de8..c7ddf8c 100644
--- a/lib/libalpm/conflict.h
+++ b/lib/libalpm/conflict.h
@@ -34,6 +34,8 @@ struct __pmconflict_t {
 	char ctarget[PKG_NAME_LEN];
 };
 
+void check_conflict(alpm_list_t *list1, alpm_list_t *list2,                     
+                alpm_list_t **baddeps, int order);
 alpm_list_t *_alpm_checkconflicts(pmdb_t *db, alpm_list_t *packages);
 alpm_list_t *_alpm_db_find_conflicts(pmdb_t *db, pmtrans_t *trans, char *root);
 
diff --git a/src/util/testdb.c b/src/util/testdb.c
index d59d010..089a78d 100644
--- a/src/util/testdb.c
+++ b/src/util/testdb.c
@@ -30,6 +30,7 @@
 
 #include <alpm.h>
 #include <alpm_list.h>
+#include <conflict.h>
 
 int _alpm_str_cmp(const void *s1, const void *s2)
 {
@@ -180,6 +181,7 @@ int main(int argc, char **argv)
     printf("missing dependency for %s : %s\n", alpm_miss_get_target(miss),
         alpm_dep_get_name(dep));
   }
+  FREELIST(data);
 
   /* check requiredby */
   for(i = alpm_db_getpkgcache(db); i; i = alpm_list_next(i)) {
@@ -187,7 +189,18 @@ int main(int argc, char **argv)
     const char *pkgname = alpm_pkg_get_name(pkg);
     alpm_list_t *rqdby = alpm_pkg_compute_requiredby(pkg);
     diffrqdby(pkgname, alpm_pkg_get_requiredby(pkg), rqdby);
+    FREELIST(rqdby);
   }
 
+  /* check conflicts */
+  check_conflict(alpm_db_getpkgcache(db), alpm_db_getpkgcache(db), &data, 0);
+  for(i = data; i; i = i->next) {
+    pmdepmissing_t *miss = alpm_list_getdata(i);
+    pmdepend_t *dep = alpm_miss_get_dep(miss);
+    printf("%s conflicts with %s\n", alpm_miss_get_target(miss),
+    	alpm_dep_get_name(dep));
+  }
+  FREELIST(data);  
+
   cleanup(retval);
 }
